// ICoordinate.aidl
package com.beidou.BDServer;

import com.beidou.BDServer.gnss.data.coordinate.ElpseData;
import com.beidou.BDServer.gnss.data.coordinate.ProjectionData;
import com.beidou.BDServer.gnss.data.coordinate.ElpsConvertData;
import com.beidou.BDServer.gnss.data.coordinate.PlaneConvertData;

interface ICoordinate {

    /**
     * 坐标转换前必须初始化，然后才可以设置坐标系
     *
     * @return 是否成功
     */
    boolean init();

      /**
       * 设置源椭球
       *
       * @param elpse 源椭球
       * @return 是否成功
       */
    boolean setSrcEllipse(inout ElpseData elpse);

    /**
     * 设置目标椭球
     *
     * @param elpse 目标椭球
     * @return 是否成功
     */
    boolean setDstEllipse(inout ElpseData elpse);

      /**
       * 设置投影参数
       *
       * @param projection 投影参数
       * @return 是否成功
       */
    boolean setProjection(inout ProjectionData projection);

    /**
     * 设置基准转换参数
     *
     * @param elps 基准转换参数
     * @return 是否成功
     */
    boolean setElpsConvert(inout ElpsConvertData elps);

    /**
     * 初始化坐标系参数后，通过84坐标计算本地坐标
     *
     * @param wgs84blh 84椭球经度、纬度、海拔，单位：弧度,不能为空
     * @param localNeh 本地椭球坐标 北坐标、东坐标、高程，不能为空
     * @return 错误代码
     */
    int transformSrcBlhToLocalNeh(inout double[] wgs84blh,inout double[] localNeh);

    /**
     * 初始化坐标系参数后，通过本地坐标计算84坐标
     *
     * @param localNeh 本地椭球坐标 北坐标、东坐标、高程，不能为空
     * @param wgs84blh 84椭球经度、纬度、海拔，单位：弧度,不能为空
     * @return 错误代码
     */
    int transformLocalNehToSrcBlh(inout double[] localNeh,inout  double[] wgs84blh);

    /**
     * 设置水平校正参数
     *
     * @param planeData 水平校正参数
     * @return 是否成功
     */
    boolean setPlaneConvert(inout PlaneConvertData planeData);
}
