// IGnssServiceBinder.aidl
package com.beidou.BDServer;

import com.beidou.BDServer.IGnssListener;
import android.location.Location;
import com.beidou.BDServer.IReceiverListener;
import com.beidou.BDServer.gnss.data.device.DeviceInfo;
import com.beidou.BDServer.IReceiver;

 /**
  *  AIDL文件中添加接口都必须追加到末尾
  */
interface IGnssServiceBinder {

    /**
     * Set the frequency of notification.
     * <p>The frequency of notification may be controlled using the
     * minTime and minDistance parameters. If minTime is greater than 0,
     * the LocationManager could potentially rest for minTime milliseconds
     * between location updates to conserve power. If minDistance is greater than 0,
     * a location will only be broadcasted if the device moves by minDistance meters.
     * To obtain notifications as frequently as possible, set both parameters to 0.<p/>
     *
     * @param minTime     the minimum time interval for notifications, in
     *                    milliseconds. This field is only used as a hint to conserve power, and actual
     *                    time between location updates may be greater or lesser than this value.
     * @param minDistance minDistance the minimum distance interval for notifications,
     *                    in meters
     */
    void requestLocationUpdates(String provider, long minTime, float minDistance, IGnssListener listener);

    /**
      *
      * send register info
      */
    void setRegisterInfo(int softwareCode, String diviceId, String registerCode,String rsapath);

    Location getLastKnownLocation(String provider);

    void removeUpdates(IGnssListener listener);

    /**
     * request ReceiverListener
     */
    void requestReceiverListener(IReceiverListener listener);

    /**
     * remove ReceiverListener
     */
    void removeReceiverListener(IReceiverListener listener);

    /**
     * get DeviceList
     */
    List<DeviceInfo> getDeviceList();

     /**
     * get Receiver
     */
    IBinder getReceiver();

    /**
     * get Version Code
     */
    int getVersionCode();

    /**
     * get Coordinate
     */
    IBinder getCoordinate();

    /**
     * get CornerSurvey
     */
    IBinder getCornerSurvey();

    /**
     * get IPipelineDetector
     */
    IBinder getPipelineDetector();

    /**
     * get IRangeFinder
     */
    IBinder getRangeFinder();

    /**
    * set the Receiver Mark
    */
    boolean setReceiverMark(int mark);

    /**
     * get IEchoSounder
     */
    IBinder getEchoSounder();
}
