// IReceiver.aidl
package com.beidou.BDServer;

import com.beidou.BDServer.gnss.data.receiver.ReceiverInfo;
import com.beidou.BDServer.gnss.data.receiver.Time;
import com.beidou.BDServer.gnss.data.receiver.ModemDialStatus;
import com.beidou.BDServer.gnss.data.receiver.GnssDataConfigList;
import com.beidou.BDServer.gnss.data.receiver.DataFrequency;
import com.beidou.BDServer.gnss.data.receiver.FileRecordInfo;
import com.beidou.BDServer.gnss.data.receiver.DataFrequencyArray;
import com.beidou.BDServer.gnss.data.receiver.NmeaTypeArray;
import com.beidou.BDServer.gnss.data.receiver.TransmissionInfoArray;
import com.beidou.BDServer.gnss.data.receiver.TransmissionInfo;
import com.beidou.BDServer.gnss.data.receiver.TransformInfo;
import com.beidou.BDServer.gnss.data.receiver.GeoidModelInfo;
import com.beidou.BDServer.gnss.data.receiver.ProjectionInfo;
import com.beidou.BDServer.gnss.data.receiver.NetworkStatus;

import com.beidou.BDServer.gnss.data.diff.PdaDiffStatus;
import com.beidou.BDServer.gnss.data.receiver.RadioInfo;
import com.beidou.BDServer.gnss.data.receiver.PpkRecordFileHeaderInfo;
import com.beidou.BDServer.gnss.data.receiver.ReceiverMode;
import com.beidou.BDServer.gnss.data.receiver.NoneMagneticSetParams;

 /**
  *  AIDL文件中添加接口都必须追加到末尾
  *
  *  Receiver cache information
  */
interface IReceiver {

    /**
     * [BDGenius的缓存]接受机信息
     */
    ReceiverInfo getReceiverInfo();

    /**
     * [BDGenius的缓存]接受机时间
     */
    Time getTime();

     /**
     * [BDGenius的缓存]GGA
     */
    byte[] getGga();

    /***
     * [BDGenius的缓存]拨号状态
     */
    ModemDialStatus getModemDialStatus();

    /**
     * [BDGenius的缓存]获取接收机IO对应输出DATA
     */
    GnssDataConfigList getGnssConfigList();

     /**
      * [BDGenius的缓存]获取RTK位置输出频率的接口
      */
    DataFrequency getDataFrequency();

    /**
     * [BDGenius的缓存]文件记录参数
     */
    FileRecordInfo getFileRecordInfo();

    /**
     * [BDGenius的缓存]文件记录状态
     */
    boolean isStopAndGoMode();

    /**
     * [BDGenius的缓存]高度截止及角
     */
    int getElevMask();

    /**
     * [BDGenius的缓存]Pdop值
     */
    int getPdopMask();

    /**
     * [BDGenius的缓存]接收机电量
     */
    int getReceiverBatteryLevel();

    /**
     * 获取接收机支持的NMEA列表
     */
    NmeaTypeArray getGnssSupportedTypes();

    /**
     * 获取接收机支持NMEA的频率
     */
    DataFrequencyArray getGnssSupportedFreqs();

    /**
     * 发送命令给主板
     */
    void sendCmdToOem(inout byte[] bts);

    /**
     * RTCM3电文
     */
    TransmissionInfoArray getTransmissionInfoList(inout byte[] data);

    /**
     * 获取CORS网络基准转换参数
     */
    void parseRtcm3DataType1021(inout TransmissionInfo rtcmData,inout TransformInfo trans);

    void parseRtcm3DataType1022(inout TransmissionInfo rtcmData,inout TransformInfo trans);

    /**
     * 获取接CORS网络大地水准面参数
     */
    void parseRtcm3DataType1023(inout TransmissionInfo rtcmData,inout GeoidModelInfo geoid);

    void parseRtcm3DataType1024(inout TransmissionInfo rtcmData,inout GeoidModelInfo geoid);

    /**
     * 获取接CORS网络投影参数
     */
    void parseRtcm3DataType1025(inout TransmissionInfo rtcmData,inout ProjectionInfo projection);

    void parseRtcm3DataType1026(inout TransmissionInfo rtcmData,inout ProjectionInfo projection);

    void parseRtcm3DataType1027(inout TransmissionInfo rtcmData,inout ProjectionInfo projection);

    /**
     * 获取气泡数据，返回的数组长度为4
     */
    int[] getEbubbleMatrix();

    /**
     * 获取BDGenius中待发给接收机的命令数
     */
     int getGnssServerCmdSize();

     /**
      * 设置feature.hcc文件，中英文
      */
     boolean setFeature(String type);

     /**
      * 获取BDGenius中的手部差分信息
      */
     PdaDiffStatus getPdaDiffStatus();

     /***
      * [BDGenius的缓存]内置网络登录状态
      */
     NetworkStatus getCacheNetworkStatus();

     /**
      * 清除等待发送的命令
      */
     void cleanWaitCmds();

      /**
       * 获取电台信息，刚连接上是不准确的，有些是默认值。
       */
      RadioInfo getRadioInfo();

      /**
       * 获取当前是否允许GnssTool模拟位置
       */
      boolean isAllowMockLocation();

      /**
       * 开启、关闭本地PPK记录文件
       */
      boolean startFileRecord(boolean isStart,String filePath);

      /**
      *PPK文件头写入
      */
      boolean writeFileHeader(inout PpkRecordFileHeaderInfo ppkRecordFileHeaderInfo);

      /**
      * PPK文件是否已经开始记录
      */
      boolean isStartPdaStopAndGo();

      /**
       * [BDGenius的缓存]高程偏移
       */
      double getHeightOffset();

      /**
      *  省电模式
      */
     ReceiverMode getReceiverMode();

      /**
       * 是否支持无磁倾斜
       */
      boolean isSupportedNoneMagnetic();

     /**
      * [BDGenius的缓存]倾斜测量参数
      */
      NoneMagneticSetParams getCacheNoneMagneticSetParams();
}
