// IReceiverListener.aidl
package com.beidou.BDServer;

import com.beidou.BDServer.gnss.data.receiver.SatelliteNumber;
import com.beidou.BDServer.gnss.data.SatelliteInfo;
import com.beidou.BDServer.gnss.data.receiver.PositionInfo;
import com.beidou.BDServer.gnss.data.receiver.Course;
import com.beidou.BDServer.gnss.data.receiver.Position;
import com.beidou.BDServer.gnss.data.receiver.DopsInfo;
import com.beidou.BDServer.gnss.data.receiver.WorkWay;
import com.beidou.BDServer.gnss.data.receiver.BaseParams;
import com.beidou.BDServer.gnss.data.receiver.GnssDataConfigList;
import com.beidou.BDServer.gnss.data.receiver.NmeaData;
import com.beidou.BDServer.gnss.data.receiver.EbubbleInfo;
import com.beidou.BDServer.gnss.data.receiver.MagnetometerInfo;
import com.beidou.BDServer.gnss.data.receiver.BasePositionInfoArray;
import com.beidou.BDServer.gnss.data.receiver.ReceiverInfo;
import com.beidou.BDServer.gnss.data.receiver.DataFrequency;
import com.beidou.BDServer.gnss.data.receiver.FileRecordStatus;
import com.beidou.BDServer.gnss.data.receiver.FileRecordInfo;
import com.beidou.BDServer.gnss.data.receiver.Baudrate;
import com.beidou.BDServer.gnss.data.receiver.ModemCommunicationMode;
import com.beidou.BDServer.gnss.data.receiver.ModemDialStatus;
import com.beidou.BDServer.gnss.data.receiver.CsdInfo;
import com.beidou.BDServer.gnss.data.receiver.ModemDialParams;
import com.beidou.BDServer.gnss.data.receiver.ReceiverWifiInfo;
import com.beidou.BDServer.gnss.data.receiver.PowerStatus;
import com.beidou.BDServer.gnss.data.receiver.ModemSignal;
import com.beidou.BDServer.gnss.data.receiver.ModemBandMode;
import com.beidou.BDServer.gnss.data.receiver.RadioChannelArray;
import com.beidou.BDServer.gnss.data.receiver.RadioInfo;
import com.beidou.BDServer.gnss.data.receiver.NetworkStatus;
import com.beidou.BDServer.gnss.data.receiver.GprsInfo;
import com.beidou.BDServer.gnss.data.receiver.CorsInfo;
import com.beidou.BDServer.gnss.data.receiver.DataSourceList;
import com.beidou.BDServer.gnss.data.receiver.ExpireDate;
import com.beidou.BDServer.gnss.data.receiver.TransformInfo;
import com.beidou.BDServer.gnss.data.receiver.GeoidModelInfo;
import com.beidou.BDServer.gnss.data.receiver.ProjectionInfo;
import com.beidou.BDServer.gnss.data.receiver.DataFrequencyArray;
import com.beidou.BDServer.gnss.data.receiver.WorkModeParams;
import com.beidou.BDServer.gnss.data.receiver.WorkModeStatus;
import com.beidou.BDServer.gnss.data.receiver.RadioChannelInspectArray;
import com.beidou.BDServer.gnss.data.receiver.ReceiverMode;
import com.beidou.BDServer.gnss.data.receiver.NoneMagneticTiltInfo;
import com.beidou.BDServer.gnss.data.receiver.NoneMagneticSetParams;

// Declare any non-default types here with import statements

/**
 *  AIDL文件中添加接口都必须追加到末尾
 */
interface IReceiverListener {

    /***** 处理CHC_MESSAGE_TYPE_GNSS**************************************************************/
    /**
     * 获取接收机当前搜索到的星座数,RECEIVER_ASW_GET_GNSS_SATELLITE_CONSTELLATION
     */
    void getSatelliteConstellations(in int constellation);

    /**
     * 获取接收机卫星使用情况,RECEIVER_ASW_GET_GNSS_SATELLITE_USEDNUM
     */
    void getSatelliteUsedNums(inout SatelliteNumber satNumbers);

    /**
     * 接收机输出卫星数据,MRECEIVER_ASW_SET_GNSS_SATELLITEDATA
     */
    void getSatelliteInfos(inout SatelliteInfo[] satelliteInfoArray);

    /**
     * 接收机位置信息输出,RECEIVER_ASW_SET_GNSS_POSDATA
     */
    void getPositionEx(inout PositionInfo positionInfo,inout Course course);

    /**
     * 移动站在RTK差分状态下输出的基站坐标,RECEIVER_ASW_SET_GNSS_BASEPOSDATA
     */
    void getBasePosition(inout Position position);

    /**
     * 接收机输出DOPS数据,RECEIVER_ASW_SET_GNSS_DOPSDATA
     */
    void getGnssDops(inout DopsInfo info);

    /**
     * 接收机输出GGA数据,RECEIVER_ASW_SET_GNSS_GPGGA
     */
    void getGpggaData(inout byte[] bts);

    /**
     * 获取接收机基站参数,RECEIVER_ASW_GET_GNSS_BASEPARAM
     */
    void getBaseParams(inout BaseParams params,inout WorkWay way);

    /**
     * 获取接收机电台，网络，及串口的工作情况(IO是否启用),RECEIVER_ASW_GET_GNSS_IOENABLE
     */
    void getIoEnable(inout boolean[] ioEnable);

    /**
     * 获取接收机IO对应输出DATA,RECEIVER_ASW_GET_GNSS_IODATA
     */
    void getIoData(inout GnssDataConfigList list);

    /**
     * 获取接收机指定io的NEMA输出列表,RECEIVER_ASW_GET_GNSS_NMEAOUTPUTLIST
     */
    void getNmeaOutputList(inout NmeaData[] nmeaArray);

    /**
     * 获取接收机PDOP限制值,RECEIVER_ASW_GET_GNSS_PDOPMASK
     */
    void getGnssPdopMask(in int pdopMask);

    /**
     * 获取接收机高度截止角,RECEIVER_ASW_GET_GNSS_ELEVMASK
     */
    void getGnssElevmask(in int pdopMask);

     /**
     * 倾斜传感器数据按固定频率输出,RECEIVER_ASW_SET_EBUBBLE_DATA
     */
    void getEbubbleInfo(inout EbubbleInfo info);

    /**
     * 陀螺仪数据按固定频率输出,RECEIVER_ASW_SET_MAGNETIC_DATA
     */
    void getMagnetometerInfo(inout MagnetometerInfo info);

    /**
     * 获取接接收机高级基准站信息列表,RECEIVER_ASW_GET_GNSS_BASEPOSITIONLIST
     */
    void getBasePositionList(inout BasePositionInfoArray baseList);

     /**
     * 获取接收机高级基准站平移量,RECEIVER_ASW_GET_GNSS_BASEPOSTIONDIFF
     */
    void getBasePositionDifference(in float diff);

    /**
     * CHCGetTransmissionInfo,RECEIVER_ASW_GET_GNSS_TRANSMISSIONINFO
     */
    void getTransmissionInfo(inout byte[] data);

    /**
     * 获取RTK位置输出频率的接口,RECEIVER_CMD_GET_POS_DATA_FREQUENCY
     */
    void getPosDataFrequency(inout DataFrequency frequency);

    /***** 处理CHC_MESSAGE_TYPE_SYSTEM************************************************************/

    /**
     * 接收机信息,RECEIVER_ASW_GET_RECEIVER_INFO
     */
    void getReceiverInfo(inout ReceiverInfo info);

    /**
     * 获取接收机注册码,RECEIVER_ASW_GET_REGCODE
     */
    void getRegCode(in String regCode);

     /**
     * 查询文件记录状态,RECEIVER_ASW_GET_FILERECORD_STATUS
     */
    void getFileRecordStatus(inout FileRecordStatus status);

    /**
     * 查询文件记录参数,RECEIVER_ASW_GET_FILERECORD_PARAM
     */
    void getFileRecordParams(inout FileRecordInfo info);

    /**
     * 获取文件是否自动记录,RECEIVER_ASW_GET_FILERECORD_AUTO_START
     */
    void getFileRecordAutoStart(in boolean isAuto);

     /**
     * 获取接收机串口波特率,RECEIVER_ASW_GET_RECEIVER_COM_BAUDRATE
     */
    void getComBaudrate(inout Baudrate baudrate);

     /**
     * 获取接收机注册时间,RECEIVER_ASW_GET_EXPIREDATE
     */
    void getExpireDate(in ExpireDate date);

     /**
     * 获取接收机电池电量,RECEIVER_ASW_GET_BATTERYLIFE
     */
    void getBattteyLife(in int baudrate);

    /***** 处理CHC_MESSAGE_TYPE_PDA***************************************************************/
    /**
     * 获取3G模块模式,RECEIVER_ASW_GET_MODEM_COMMUNICATION_MODE
     */
    void getModemCommunicationMode(inout ModemCommunicationMode mode);

    /**
     * 获取3G模块拨号状态,RECEIVER_ASW_GET_MODEM_DIAL_STATUS
     */
    void getModemDialStatus(inout ModemDialStatus status);

    /**
     * 获取3G模块拨号状态,RECEIVER_ASW_GET_MODEM_GSM_DIAL_STATUS
     */
    void getCsdDialStatus(inout ModemDialStatus status);

     /**
     * 获取3G模块GSM拨号参数,RECEIVER_ASW_GET_MODEM_GSM_PARAM
     */
    void getCsdInfo(inout CsdInfo info);

    /**
     * 获取3G模块拨号参数,RECEIVER_ASW_GET_MODEM_DIAL_PARAM
     */
    void getModemAutoDialParams(inout ModemDialParams params);

    /**
     * 获取3G模块是否自动拨号,RECEIVER_ASW_GET_MODEM_AUTO_DIALON
     */
    void getModemAutoDial(in boolean autoDial);

     /**
     * 获取3G模块是否自动拨号,RECEIVER_ASW_GET_MODEM_AUTO_DIALON
     */
    void getModemAutoPowerOn(in boolean autoPowerOn);

     /**
     * 获取3G模块电源状态,RECEIVER_ASW_GET_MODEM_POWER_STATUS
     */
    void getModemPowerStatus(inout PowerStatus status);

    /**
     * WIFI是否自动上电 ,获取WIFI模块自动开启,RECEIVER_ASW_GET_WIFI_AUTO_POWERON
     */
    void getWifiAutoPowerOn(in boolean auto);

    /**
     * 获取WIFI模块参数,RECEIVER_ASW_GET_WIFI_PARAM
     */
    void getWifiInfo(inout ReceiverWifiInfo info);

     /**
     * 获取WIFI打开状态,RECEIVER_ASW_GET_WIFI_STATUS
     */
    void getWifiStatus(inout PowerStatus status);

    /**
     * 获取3g模块信号强度,RECEIVER_ASW_GET_MODEM_SIGNAL
     */
    void getModemSignal(inout ModemSignal status);

    /**
     * 获取3G模块频段,RECEIVER_ASW_GET_MODEM_BAND_MODE
     */
    void getModemBandMode(inout ModemBandMode status);

    /***** 处理CHC_MESSAGE_TYPE_DATALINK**********************************************************/
    /**
     * 获取接收机电台模块打开状态,RECEIVER_ASW_GET_RADIO_POWER_STATUS
     */
    void getRadioPowerStatus(inout PowerStatus status);

    /**
     * 获取接收机电台信道列表,RECEIVER_ASW_GET_RADIO_CHANNELLIST
     */
    void getRadioChannelList(inout RadioChannelArray channelList);

     /**
     * 获取接收机电台信息,RECEIVER_ASW_GET_RADIO_INFO
     */
    void getRadioInfo(inout RadioInfo info);

    /**
     * 获取接收机GPRS模块状态,RECEIVER_ASW_GET_GPRS_STATUS
     */
    void getGprsStatus(inout NetworkStatus status);

    /**
     * 获取接收机GPRS模块信息,RECEIVER_ASW_GET_GPRS_INFO
     */
    void getGprsInfo(inout GprsInfo info);

    /**
     * 获取接收机CORS设置信息,RECEIVER_ASW_GET_CORS_INFO
     */
    void getCorsInfo(inout CorsInfo info);

     /**
     * 获取源列表,RECEIVER_ASW_GET_SOURCE_TABLE
     */
    void getSourceTable(inout DataSourceList data);

     /**
     * 获取接收机电台是否自动开启,RECEIVER_ASW_GET_RADIO_AUTO_POWERON
     */
    void getRadioAutoPowerOn(in boolean autoPowerOn);

    /**
     * 获取接收机GPRS模块是否自动登陆,RECEIVER_ASW_GET_GPRS_AUTO_LOGIN
     */
    void getGprsLoginMdl(in boolean autoPowerOn);

    /***** 处理发命令出错回调**************************************************************/

    /**
     * 更新静态参数出错
     */
    void UpdateFileRecordParamsError();

    /**
     * 更新GPRS参数出错
     */
    void GetCmdUpdateError();

    /**
     * 获取到差分数据后给予提示，目前指的是手部网络
     */
    void getDiffDataTip();

    /**
     * CORS网络基准转换参数【9249版本及以上支持】
     */
    void getTransformInfo(inout TransformInfo transformInfo);

    /**
     * CORS网络大地水准面参数【9249版本及以上支持】
     */
    void getGeoidModelInfo(inout GeoidModelInfo geoidModelInfo);

    /**
     * CORS网络投影参数【9249版本及以上支持】
     */
    void getProjectionInfo(inout ProjectionInfo projectionInfo);

    /**
     * 静态采样间隔列表
     */
     void getFileRecordFrequencyList(inout DataFrequencyArray dataFrequencyArray);

     /**
      * 工作模式参数
      */
      void getWorkModeParams(inout WorkModeParams workModeParams);

     /**
      * 工作模式状态
      */
      void getWorkModeStatus(inout WorkModeStatus workModeStatus);

     /**
      *  获取星基注册时间，RECEIVER_ASW_GET_STAR_DIFF_EXPIRE_DATE
     */
      void getStarDiffExpireDate(in ExpireDate date);

      /**
       * 获取信道检测
       */
      void getRadioChannelInspectArray(inout RadioChannelInspectArray radioChannelInspectArray);

     /**
      * 获取不支持信道检测
      */
      void getIsSupportRadioChannelInspect(in boolean isSupport);

     /**
     * 获取接收机模式
     */
     void getReceiverMode(inout ReceiverMode mode);

     /**
      * 无磁倾斜数据
      */
      void getNoneMagneticTiltInfo(inout NoneMagneticTiltInfo info);

      /**
       * 无磁倾斜参数数据
       */
       void getNoneMagneticSetParams(inout NoneMagneticSetParams params);

}
